==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/en/xtsepHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "separation of lines to multiple files"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-d*/
#define DIRT "directory path+attribute name"
#define DIRC "directory path to which partitioned files are output"

/*-p*/
#define FRCT "forcible directory creation"
#define FRCC "The path is forcibly created if it does not exist."

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "An input file is partitioned according to the value of a certain attribute."

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtsep -d './dat-$(date)' -i dat.xt\n\
xtsep -d './dat-$(date)$(time)' -i dat.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtcat"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-2.0.1.tar.gz: musashi-core-2.0.1/help/en/xtsepHelp.h <==
#include "commonHelp.h"
/*============================================================================*/
/* Management of messages common to command help, man, and musashi GUI                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "separation of lines to multiple files"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-d*/
#define DIRT "directory path+attribute name"
#define DIRC "directory path to which partitioned files are output"

/*-p*/
#define FRCT "forcible directory creation"
#define FRCC "The path is forcibly created if it does not exist."

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "xtsep partitions the input according to the value of the attribute. The path and file name for each partition are specified by -d parameter. An attribute name is used as the file name by adding the prefix $ before the attribute name. For example, in the definition '-d /tmp/data/$date', $date is an attribute name. Thus, this command partitions data according to the unique value of date. For date=20010101, the output will be /tmp/data/20010101. Parenthesis is needed around the attribute if you want to append a file extension '.xt' after the attribute name (i.e. /tmp/data/$(date).xt). "

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtsep -d './dat-$(date)' -i dat.xt\n\
xtsep -d './dat-$(date)$(time)' -i dat.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtcat"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
